jingle/jingle.h
changeset 20 72e53665328e
parent 18 d0ddcfd31eb8
child 21 147f131382dd
--- a/jingle/jingle.h	Fri Jun 11 01:56:34 2010 +0200
+++ b/jingle/jingle.h	Sun Jun 13 02:25:51 2010 +0200
@@ -63,7 +63,7 @@
   /* Random session identifier generated by the initator. */
   const gchar *sid;
 
   /* Doubly-linked list of JingleContentNode. */
   GSList *content;
 
 } JingleNode;
@@ -98,7 +98,7 @@
    * method */
   LmMessageNode *transport;
 
-} JingleContentNode;
+} JingleContent;
 
 struct JingleActionList {
   const gchar  *name;
@@ -63,7 +63,7 @@
   const gchar *sid;
 
-  /* Doubly-linked list of JingleContentNode. */
+  /* Doubly-linked list of JingleContent. */
   GSList *content;
 